policykit-gnome r58 - trunk/polkit-gnome



Author: matthiasc
Date: Fri Aug  8 14:52:55 2008
New Revision: 58
URL: http://svn.gnome.org/viewvc/policykit-gnome?rev=58&view=rev

Log:
Use standard icon names for the default icons, since gnome-icon-theme
has stopped shipping the legacy symlinks.


Modified:
   trunk/polkit-gnome/polkit-gnome-toggle-action.c

Modified: trunk/polkit-gnome/polkit-gnome-toggle-action.c
==============================================================================
--- trunk/polkit-gnome/polkit-gnome-toggle-action.c	(original)
+++ trunk/polkit-gnome/polkit-gnome-toggle-action.c	Fri Aug  8 14:52:55 2008
@@ -334,9 +334,9 @@
  * user. By toggling the action again, the negative authorization will
  * be revoked.
  *
  * Default behavior is defined as having the icon_name be 'stock_lock'
  * by default except for the YES PolicyKit answer where it's set to
- * 'stock_lock-open'. No tooltips are set. The label and short-label
+ * 'security-low'. No tooltips are set. The label and short-label
  * will be 'locked_label' everywhere except in the YES state where
  * it's set to 'unlocked-label'. When authentication is underway, the
  * label will be "Authenticating..." and icon_name is untouched. If
@@ -372,35 +372,35 @@
                                       "self-blocked-short-label", locked_label,
                                       "self-blocked-label",       locked_label,
                                       "self-blocked-tooltip",     NULL,
-                                      "self-blocked-icon-name",   "stock_lock",
+                                      "self-blocked-icon-name",   "security-medium",
 
                                       "no-visible",       TRUE,
                                       "no-sensitive",     FALSE,
                                       "no-short-label",   locked_label,
                                       "no-label",         locked_label,
                                       "no-tooltip",       NULL,
-                                      "no-icon-name",     "stock_lock",
+                                      "no-icon-name",     "security-medium",
                                       
                                       "auth-visible",     TRUE,
                                       "auth-sensitive",   TRUE,
                                       "auth-short-label", locked_label,
                                       "auth-label",       locked_label,
                                       "auth-tooltip",     NULL,
-                                      "auth-icon-name",   "stock_lock",
+                                      "auth-icon-name",   "security-medium",
                                       
                                       "yes-visible",      TRUE,
                                       "yes-sensitive",    TRUE,
                                       "yes-short-label",  unlocked_label,
                                       "yes-label",        unlocked_label,
                                       "yes-tooltip",      NULL,
-                                      "yes-icon-name",    "stock_lock-open",
+                                      "yes-icon-name",    "security-low",
 
                                       "auth-underway-visible",      TRUE,
                                       "auth-underway-sensitive",    TRUE,
                                       "auth-underway-short-label",  _("Authenticating..."),
                                       "auth-underway-label",        _("Authenticating..."),
                                       "auth-underway-tooltip",      NULL,
-                                      "auth-underway-icon-name",    "stock_lock",
+                                      "auth-underway-icon-name",    "security-medium",
                                       
                                       "master-visible",   TRUE,
                                       "master-sensitive", TRUE,
@@ -408,7 +408,7 @@
         return toggle_action;
 }
 
-/*----------------------------------------------------------------------------------------------------*/
+/*---------------------------------------------------------------------------------security-medium-------------------*/
 
 static void
 polkit_gnome_toggle_action_set_auth_underway_visible (PolKitGnomeToggleAction *action, gboolean visible)
@@ -334,9 +334,9 @@
  * be revoked.
  *
- * Default behavior is defined as having the icon_name be 'stock_lock'
+ * Default behavior is defined as having the icon_name be 'security-medium'
  * by default except for the YES PolicyKit answer where it's set to



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]